@@ -1,6 +1,6 @@
-// { dg-require-namedlocale "" }
+// { dg-require-namedlocale "en_US.UTF-8" }
 
-// Copyright (C) 2003, 2005, 2009 Free Software Foundation, Inc.
+// Copyright (C) 2003, 2005, 2009, 2010 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -38,7 +38,7 @@ void test04()
   
   VERIFY( n1 != wfilebuf::traits_type::eof() );
   VERIFY( n2 != wfilebuf::traits_type::eof() );
-  VERIFY( f != NULL );
+  VERIFY( f );
 }
 
 int main()
